
/*-----------------------------------------------------
GENDER GAPS WITHIN COUPLES:
EVIDENCE OF TIME RE-ALLOCATIONS 
DURING COVID-19 IN ARGENTINA
--------------------------------------------------------

Journal of Family and Economic Issues

Date: February, 2021
-----------------------------------------------------*/


*-------------------------------------------------------
* directory and data set 
*-------------------------------------------------------

* Write the database folder in the next line
clear all
global data "C:\..."
cd "$data"
use TimeSurvey_ArgCovid, clear


*-------------------------------------------------------
* tables and results
*-------------------------------------------------------

* TABLE 1.
summ bothworking change_hswork_h ///
change_hswork_m workfromhome domesticemp 
summ low_educ mid_educ age lowinc 
tab n_children   
summ north central south caba


* TABLE 2.
// Panel (A)
summ hswork_h hswork_m hs_hwork_h ///
			hs_hwork_m hsccare_h hsccare_m  ///
			hsedsupp_h hsedsupp_m hsleisure_h ///
			hsleisure_m 
			
// Panel (A) - (i)
foreach var of varlist  gap_work gap_hwork ///
						gap_ccare gap_edsupp gap_leisure {
						ttest `var' == 0 
}	
			
// Panel (B)
summ hswork_*_1 hs_hwork_*_1 hsccare_*_1 ///
			hsedsupp_*_1 hsleisure_*_1 		
	
// Panel (B) - (i)
foreach var of varlist  gap_work_1 gap_hwork_1 ///
					gap_ccare_1 gap_edsupp_1 gap_leisure_1 {
						ttest `var' == 0 
}	

// Panel (C)
foreach var of varlist gapchange_*   {
							ttest `var' == 0 
}	


* TABLE 3.  [full estimates reported in Table B.2]
local main_vars = "bothworking workfromhome change_hswork_h change_hswork_m change_whome domesticemp"
local set_controls = "low_educ mid_educ age lowinc n_children north central_south"

// Housework
reg gapchange_hwork  `main_vars' 
outreg2 using "$data\table3.xls", lab replace ctitle(Column 1)
reg gapchange_hwork  `main_vars'  `set_controls' 
outreg2 using "$data\table3.xls", lab append ctitle(Column 2)

// Childcare
reg gapchange_ccare  `main_vars' 
outreg2 using "$data\table3.xls", lab append ctitle(Column 3)
reg gapchange_ccare  `main_vars'  `set_controls' 
outreg2 using "$data\table3.xls", lab append ctitle(Column 4)

// Educational Childcare
reg gapchange_edsupp  `main_vars' 
outreg2 using "$data\table3.xls", lab append ctitle(Column 5)
reg gapchange_edsupp  `main_vars'  `set_controls' 
outreg2 using "$data\table3.xls", lab append ctitle(Column 6)


*-------------------------------------------------------
* tables and results - appendix B
*-------------------------------------------------------

* TABLE B.1.
summ hh_woutc lowinc medinc highinc 
summ family1c family2c family3c  ///
			familymore3c n_children if n_children!=0
summ north  central caba south age  /// 
			low_educ mid_educ /// 
			high_educ man_works woman_works ///
			hswork_week_h hswork_week_m /// 
			hs_hwork_h hs_hwork_m
summ hsccare_h hsccare_m hsedsupp_h ///
			hsedsupp_m if n_children!=0


* TABLE B.3.
ipfweight education region income hh_woutc, ///
					gen(wgt) val(31.9 40.0 28.1 16.3 74.8 8.9 44.4 19.3 36.3 75.5 24.5) maxit(100) 
								
local main_vars = "bothworking workfromhome change_hswork_h change_hswork_m change_whome domesticemp"
local set_controls = "low_educ mid_educ age lowinc n_children north central_south"

// Housework
reg gapchange_hwork  `main_vars'  `set_controls'  [pw=wgt]
outreg2 using "$data\tableB3.xls", lab append 

// Childcare
reg gapchange_ccare  `main_vars'  `set_controls'  [pw=wgt]
outreg2 using "$data\tableB3.xls", lab append 

// Educational Childcare
reg gapchange_edsupp  `main_vars'  `set_controls'  [pw=wgt]
outreg2 using "$data\tableB3.xls", lab append 






